@@ -72,11 +72,14 @@ spool_store_get_type (CamelSpoolStore *spool_store,
 	gchar *path;
 
 	service = CAMEL_SERVICE (spool_store);
-	settings = camel_service_get_settings (service);
+
+	settings = camel_service_ref_settings (service);
 
 	local_settings = CAMEL_LOCAL_SETTINGS (settings);
 	path = camel_local_settings_dup_path (local_settings);
 
+	g_object_unref (settings);
+
 	/* Check the path for validity while we have the opportunity. */
 
 	if (path == NULL || *path != '/') {
@@ -193,12 +196,12 @@ scan_dir (CamelStore *store,
 	gchar from[80];
 	FILE *fp;
 
-	d(printf("checking dir '%s' part '%s' for mbox content\n", root, path));
+	d (printf ("checking dir '%s' part '%s' for mbox content\n", root, path));
 
 	/* look for folders matching the right structure, recursively */
 	if (path) {
 		name = alloca (strlen (root) + strlen (path) + 2);
-		sprintf(name, "%s/%s", root, path);
+		sprintf (name, "%s/%s", root, path);
 	} else
 		name = (gchar *) root;  /* XXX casting away const */
 
@@ -239,11 +242,11 @@ scan_dir (CamelStore *store,
 	}
 
 	while ((d = readdir (dir))) {
-		if (strcmp(d->d_name, ".") == 0
-		    || strcmp(d->d_name, "..") == 0)
+		if (strcmp (d->d_name, ".") == 0
+		    || strcmp (d->d_name, "..") == 0)
 			continue;
 
-		tmp = g_strdup_printf("%s/%s", name, d->d_name);
+		tmp = g_strdup_printf ("%s/%s", name, d->d_name);
 		if (g_stat (tmp, &st) == 0) {
 			if (path)
 				fname = g_strdup_printf (
@@ -258,11 +261,11 @@ scan_dir (CamelStore *store,
 				folder = camel_object_bag_peek (
 					store->folders, fname);
 				if (folder == NULL) {
-					fp = fopen(tmp, "r");
+					fp = fopen (tmp, "r");
 					if (fp != NULL) {
 						isfolder = (st.st_size == 0
 							    || (fgets (from, sizeof (from), fp) != NULL
-								&& strncmp(from, "From ", 5) == 0));
+								&& strncmp (from, "From ", 5) == 0));
 						fclose (fp);
 					}
 				}
@@ -346,11 +349,14 @@ get_folder_info_elm (CamelStore *store,
 	gchar *path;
 
 	service = CAMEL_SERVICE (store);
-	settings = camel_service_get_settings (service);
+
+	settings = camel_service_ref_settings (service);
 
 	local_settings = CAMEL_LOCAL_SETTINGS (settings);
 	path = camel_local_settings_dup_path (local_settings);
 
+	g_object_unref (settings);
+
 	visited = g_hash_table_new (inode_hash, inode_equal);
 
 	if (scan_dir (
@@ -402,11 +408,14 @@ spool_store_get_name (CamelService *service,
 	gchar *path;
 
 	spool_store = CAMEL_SPOOL_STORE (service);
-	settings = camel_service_get_settings (service);
+
+	settings = camel_service_ref_settings (service);
 
 	local_settings = CAMEL_LOCAL_SETTINGS (settings);
 	path = camel_local_settings_dup_path (local_settings);
 
+	g_object_unref (settings);
+
 	if (brief)
 		return path;
 
@@ -457,7 +466,7 @@ spool_store_get_folder_sync (CamelStore *store,
 	gchar *name;
 	gchar *path;
 
-	d(printf("opening folder %s on path %s\n", folder_name, path));
+	d (printf ("opening folder %s on path %s\n", folder_name, path));
 
 	spool_store = CAMEL_SPOOL_STORE (store);
 	type = spool_store_get_type (spool_store, error);
@@ -466,14 +475,17 @@ spool_store_get_folder_sync (CamelStore *store,
 		return NULL;
 
 	service = CAMEL_SERVICE (store);
-	settings = camel_service_get_settings (service);
+
+	settings = camel_service_ref_settings (service);
 
 	local_settings = CAMEL_LOCAL_SETTINGS (settings);
 	path = camel_local_settings_dup_path (local_settings);
 
+	g_object_unref (settings);
+
 	/* we only support an 'INBOX' in mbox mode */
 	if (type == CAMEL_SPOOL_STORE_MBOX) {
-		if (strcmp(folder_name, "INBOX") != 0) {
+		if (strcmp (folder_name, "INBOX") != 0) {
 			g_set_error (
 				error, CAMEL_STORE_ERROR,
 				CAMEL_STORE_ERROR_NO_FOLDER,
@@ -632,11 +644,14 @@ spool_store_get_full_path (CamelLocalStore *local_store,
 	gchar *path;
 
 	service = CAMEL_SERVICE (local_store);
-	settings = camel_service_get_settings (service);
+
+	settings = camel_service_ref_settings (service);
 
 	local_settings = CAMEL_LOCAL_SETTINGS (settings);
 	path = camel_local_settings_dup_path (local_settings);
 
+	g_object_unref (settings);
+
 	spool_store = CAMEL_SPOOL_STORE (local_store);
 
 	switch (spool_store_get_type (spool_store, NULL)) {
